package com.ruoyi.buyerapi.service;


import com.ruoyi.buyerapi.domain.BuyerQuickMenu;

import java.util.List;

/**
 * 快捷菜单Service接口
 * 
 * @author ruoyi
 * @date 2022-10-06
 */
public interface IBuyerQuickMenuService 
{
    /**
     * 查询快捷菜单
     * 
     * @param id 快捷菜单主键
     * @return 快捷菜单
     */
    public BuyerQuickMenu selectBuyerQuickMenuById(Long id);

    /**
     * 查询快捷菜单列表
     * 
     * @param buyerQuickMenu 快捷菜单
     * @return 快捷菜单集合
     */
    public List<BuyerQuickMenu> selectBuyerQuickMenuList(BuyerQuickMenu buyerQuickMenu);

    /**
     * 查询快捷菜单信息
     *
     * @return 快捷菜单集合
     */
    public List<BuyerQuickMenu> selectBuyerQuickMenuInfo();

    /**
     * 新增快捷菜单
     * 
     * @param buyerQuickMenu 快捷菜单
     * @return 结果
     */
    public int insertBuyerQuickMenu(BuyerQuickMenu buyerQuickMenu);

    /**
     * 批量新增快捷菜单
     *
     * @param buyerQuickMenus 快捷菜单
     * @return 结果
     */
    public int batchInsertBuyerQuickMenu(List<BuyerQuickMenu> buyerQuickMenus);

    /**
     * 修改快捷菜单
     * 
     * @param buyerQuickMenu 快捷菜单
     * @return 结果
     */
    public int updateBuyerQuickMenu(BuyerQuickMenu buyerQuickMenu);

    /**
     * 批量删除快捷菜单
     * 
     * @param ids 需要删除的快捷菜单主键集合
     * @return 结果
     */
    public int deleteBuyerQuickMenuByIds(Long[] ids);

    /**
     * 删除快捷菜单信息
     * 
     * @param id 快捷菜单主键
     * @return 结果
     */
    public int deleteBuyerQuickMenuById(Long id);
}
